<div align="center">
    <img src="https://forgineer.pythonanywhere.com/static/pandas_liteql/pandas-liteql-logo.png" alt="pandas-liteql-logo.png"><br>
</div>

---

# pandas-liteql
**pandas-liteql** is an extension for pandas, enabling users to execute SQL statements on pandas DataFrames using in-memory SQLite, streamlining data manipulation and analysis tasks. Documentation comming soon...
